@@ -28,16 +28,15 @@ PrefDialog::PrefDialog( QWidget *parent )
   hb->addWidget( label );
 
   checkBoxes = new QList<QCheckBox>;
-  for( int i = 0; i < 3; i++ )
+  for( int i = 0; i < 2; i++ )
   {
     QCheckBox *cb = new QCheckBox( this );
     checkBoxes->append( cb );
     vb->addWidget( cb );
   }
 
-  checkBoxes->at(0)->setText( i18n("Show stats on Game Over") );
-  checkBoxes->at(1)->setText( i18n("Show highscores on Game Over") );
-  checkBoxes->at(2)->setText( i18n("Player can destroy Powerups") );
+  checkBoxes->at(0)->setText( i18n("Show highscores on Game Over") );
+  checkBoxes->at(1)->setText( i18n("Player can destroy Powerups") );
 
   hb = new QHBoxLayout( vb );
 
@@ -68,9 +67,8 @@ void PrefDialog::readConfig()
 
     spinShips->setValue( conf->readNumEntry( "numShips", 3 ) );
 
-    checkBoxes->at(0)->setChecked( conf->readBoolEntry( "showStats", true ) );
-    checkBoxes->at(1)->setChecked( conf->readBoolEntry( "showHiscores" , true ) );
-    checkBoxes->at(2)->setChecked( conf->readBoolEntry( "canDestroyPowerups", true ) );
+    checkBoxes->at(0)->setChecked( conf->readBoolEntry( "showHiscores" , false ) );
+    checkBoxes->at(1)->setChecked( conf->readBoolEntry( "canDestroyPowerups", true ) );
   }
 }
 
@@ -82,9 +80,8 @@ void PrefDialog::slotOk()
   {
     conf->setGroup( "Preferences" );
     conf->writeEntry( "numShips", spinShips->value() );
-    conf->writeEntry( "showStats", checkBoxes->at(0)->isChecked() );
-    conf->writeEntry( "showHiscores", checkBoxes->at(1)->isChecked() );
-    conf->writeEntry( "canDestroyPowerups", checkBoxes->at(2)->isChecked() );
+    conf->writeEntry( "showHiscores", checkBoxes->at(0)->isChecked() );
+    conf->writeEntry( "canDestroyPowerups", checkBoxes->at(1)->isChecked() );
 
     conf->sync();
 
