@@ -1,4 +1,9 @@
-//	--- toplevel.cpp ---
+/*
+ * KAsteroids - Copyright (c) Martin R. Jones 1997
+ *
+ * Part of the KDE project
+ */
+
 #include <qaccel.h>
 #include <qlabel.h>
 #include <qlayout.h>
@@ -19,6 +24,7 @@
 #include <kiconloader.h>
 #include <kaction.h>
 #include <kstdaction.h>
+#include <kstdgameaction.h>
 #include <kaudioplayer.h>
 
 #include "toplevel.h"
@@ -283,7 +289,7 @@ KAstTopLevel::KAstTopLevel() : KMainWindow(0)
 
     accel->readSettings();
 
-    createMenuBar();
+    initKAction();
 
     setCentralWidget( mainWin );
 
@@ -306,12 +312,11 @@ KAstTopLevel::~KAstTopLevel()
 #endif
 }
 
-void KAstTopLevel::createMenuBar()
+void KAstTopLevel::initKAction()
 {
-    KStdAction::openNew( this, SLOT( slotNewGame() ), actionCollection(), "game_new" );
-    (void)new KAction( i18n("Show &Highscores..."), 0, this, 
-          SLOT( slotShowHighscores() ), actionCollection(), "game_hiscores" );
-    KStdAction::quit(this, SLOT( slotQuit() ), actionCollection(), "game_quit");
+    KStdGameAction::gameNew( this, SLOT( slotNewGame() ), actionCollection() );
+    KStdGameAction::highscores( this, SLOT( slotShowHighscores() ), actionCollection() );
+    KStdGameAction::quit(this, SLOT( slotQuit() ), actionCollection());
 
 //settings
     KStdAction::keyBindings(this, SLOT( slotKeyConfig() ), actionCollection());
@@ -342,8 +347,7 @@ void KAstTopLevel::readSettings()
 	
     config->setGroup( "Preferences" );
 
-    showStats = config->readBoolEntry( "showStats", true );
-    showHiscores = config->readBoolEntry( "showHiscores", true );
+    showHiscores = config->readBoolEntry( "showHiscores", false );
     shipsRemain = config->readNumEntry( "numShips", 3 );
 }
 
@@ -542,10 +546,9 @@ void KAstTopLevel::slotShipKilled()
     }
     else
     {
-        KMessageBox::information(this, i18n("Game Over!"));
+        view->showText( i18n("Game Over!"), red );
         view->endGame();
-        if ( showStats )
-            doStats();
+	doStats();
         highscore->addEntry( score, level, showHiscores );
     }
 }
@@ -604,42 +607,23 @@ void KAstTopLevel::slotShowHighscores()
 
 void KAstTopLevel::doStats()
 {
-    QDialog *dlg = new QDialog( this, "Stats", true );
-
-    dlg->setCaption( kapp->makeStdCaption(i18n( "Game stats" )) );
-
-    QVBoxLayout *vb = new QVBoxLayout( dlg, 10 );
-
-    QLabel *lab = new QLabel( dlg );
-    vb->addWidget( lab );
-
-    QString r = KGlobal::locale()->formatNumber(( (float)view->hits() /
+    QString r;
+    if ( view->shots() )
+	 r = KGlobal::locale()->formatNumber(( (float)view->hits() /
 					(float)view->shots() ) * 100, 2 );
+    else
+	r = KGlobal::locale()->formatNumber( 0.0, 2 );
 
-    QString s = i18n( "kasteroids game stats:\n\n "
-		      "Score:\t%1\n "
-		      "Level:\t\t%2\n "
-		      "Shots fired:\t%3\n "
-		      "o Hit:\t%4\n "
-		      "o Missed:\t%5\n "
-		      "Hit ratio:\t%6 %%\t\t")
-      .arg(score).arg(level)
+    QString s = i18n( "Game Over\n\n"
+		      "Shots fired:\t%1\n"
+		      "  Hit:\t%2\n"
+		      "  Missed:\t%3\n"
+		      "Hit ratio:\t%4 %\t\t")
       .arg(view->shots()).arg(view->hits())
       .arg(view->shots() - view->hits())
       .arg(r);
 
-    lab->setText( s );
-
-    QPushButton *ok = new QPushButton( i18n( "&OK" ), dlg );
-    vb->addWidget( ok );
-    ok->setFocus();
-    ok->setDefault( true );
-
-    connect( ok, SIGNAL( clicked() ), dlg, SLOT( accept() ) );
-
-    dlg->exec();
-
-    delete dlg;
+    view->showText( s, green, FALSE );
 }
 
 void KAstTopLevel::slotUpdateVitals()
