@@ -1,5 +1,6 @@
-/*
-  Copyright (C) 1999,2000 Jens Hoefkens
+/* Yo Emacs, this -*- C++ -*-
+
+  Copyright (C) 1999-2001 Jens Hoefkens
   jens@hoefkens.com
   
   This program is free software; you can redistribute it and/or modify
@@ -18,6 +19,29 @@
   
 */
 
+/*
+
+  $Log: kbgboard.cpp,v $
+  Revision 1.13  2001/05/02 00:58:35  hoefkens
+  Honor the user selected font size for the board.
+
+  Revision 1.12  2001/04/12 15:54:46  porten
+  explicit double/float casts for sqrt() and pow() on Irix 6.5. Based on
+  a patch by Albert Chin-A-Young <china@thewrittenword.com>
+
+  Revision 1.11  2001/03/23 02:12:56  hoefkens
+  More configuration changes
+
+  Revision 1.10  2001/03/19 05:34:04  hoefkens
+  Engine redesign and settings changes - not yet finished
+
+  Revision 1.9  2001/03/16 07:33:50  hoefkens
+  Rewrite of the setup dialog. First (not fully working) eventsrc file.
+
+  Revision 1.8  2001/03/14 05:02:00  hoefkens
+  Font selection was broken
+
+*/
 
 /*
 
@@ -38,29 +62,103 @@
 #include <stdlib.h>
 #include <math.h>
 #include <kcolordlg.h>
-#include <kfontdialog.h>
 #include <klocale.h>
 #include <qlayout.h>
 #include <qgroupbox.h>
 #include <qbuttongroup.h>
 #include <kconfig.h>
-#include <qradiobutton.h>
 #include <qwhatsthis.h>
+#include <qvbox.h> 
+#include <kiconloader.h>
+#include <ktabctl.h>
 
 #include "version.h"
 
 
+const int CUBE_UPPER = 3;
+const int CUBE_LOWER = 4;
+
+
+/*
+ * Set the default settings in all user configurations
+ */
+void KBgBoardSetup::setupDefault()
+{
+	// default background color
+	setBackgroundColor(QColor(200, 200, 166));
+	pbc_1->setPalette(QPalette(backgroundColor()));
+
+	// checker colors
+	baseColors[0] = black;
+	baseColors[1] = white;
+	pbc_2->setPalette(QPalette(baseColors[0]));
+	pbc_3->setPalette(QPalette(baseColors[1]));
+
+	// default font
+	setFont(QFont("times", 18, QFont::Normal));
+	kf->setFont(getFont());
+
+	// short moves
+	setShortMoveMode(SHORT_MOVE_DOUBLE);
+	for (int i = 0; i < 3; i++)
+		rbMove[i]->setChecked(i == SHORT_MOVE_DOUBLE);
+
+	// pip count
+	cbp->setChecked(computePipCount = true);
+}
+
+/*
+ * User committed the changes. Save them.
+ */
+void KBgBoardSetup::setupOk()
+{
+	// font selection
+	setFont(kf->font());
+
+	// move strategy 
+	for (int i = 0; i < 3; i++)
+		if (rbMove[i]->isChecked()) setShortMoveMode(i);
+
+	// pipcount
+	computePipCount = cbp->isChecked();		
+}
+
+/*
+ * User cancelled the changes. Undo the color changes that become
+ * visible right away.
+ */
+void KBgBoardSetup::setupCancel()
+{
+	// undo background color change
+	setBackgroundColor(saveBackgroundColor);
+
+	// undo checker color changes
+	baseColors[0] = saveBaseColors[0];
+	baseColors[1] = saveBaseColors[1];
+
+	for (int i = 0; i < 30; i++)
+		cells[i]->update();
+}
+
 /*
  * Fills configuration page in the dialog nb
  */
-void KBgBoardSetup::getSetupPages(QTabDialog *nb)
+void KBgBoardSetup::getSetupPages(KDialogBase *nb)
 {
 	/*
 	 * Main Widget
 	 * ===========
 	 */
-	QWidget *w = new QWidget(nb);
-	QGridLayout *gl = new QGridLayout(w, 4, 1, 20);
+	QVBox *vbp = nb->addVBoxPage(i18n("Board"), i18n("Here you can configure the backgammon board"),
+				     kapp->iconLoader()->loadIcon(PROG_NAME, KIcon::Desktop));
+
+	/*
+	 * Need more than one page
+	 */
+	KTabCtl *tc = new KTabCtl(vbp, "board tabs");
+	
+	QWidget *w = new QWidget(tc);
+	QGridLayout *gl = new QGridLayout(w, 3, 1, nb->spacingHint());
   
 	/*
 	 * Group boxes
@@ -70,8 +168,8 @@ void KBgBoardSetup::getSetupPages(QTabDialog *nb)
 	QButtonGroup *gm = new QButtonGroup(w);
 	QGroupBox    *go = new QGroupBox(w);
 
-	ga->setTitle(i18n("Visual Appearance:"));
-	gm->setTitle(i18n("Short Move Strategy:"));
+	ga->setTitle(i18n("Colors:"));
+	gm->setTitle(i18n("Short Moves:"));
 	go->setTitle(i18n("Options:"));
 
 	gl->addWidget(ga, 0, 0);
@@ -93,51 +191,36 @@ void KBgBoardSetup::getSetupPages(QTabDialog *nb)
 	pbc_3 = new QPushButton(i18n("Color 2"), ga);
 	pbc_3->setPalette(QPalette(baseColors[1]));
 
-	QPushButton *pbf = new QPushButton(i18n("Font"), ga);
-
-	blc->addWidget(pbc_2, 0, 0, AlignHCenter);
-	blc->addWidget(pbc_3, 1, 0, AlignHCenter);
-	blc->addWidget(pbc_1, 0, 1, AlignHCenter);
-	blc->addWidget(pbf,   1, 1, AlignHCenter);
+	blc->addWidget(pbc_2, 0, 0);
+	blc->addWidget(pbc_3, 0, 1);
+	blc->addMultiCellWidget(pbc_1, 1, 1, 0, 1);
 
 	connect(pbc_1, SIGNAL(clicked()), this, SLOT(selectBackgroundColor()));
 	connect(pbc_2, SIGNAL(clicked()), this, SLOT(selectBaseColorOne()));
 	connect(pbc_3, SIGNAL(clicked()), this, SLOT(selectBaseColorTwo()));
-	connect(pbf,   SIGNAL(clicked()), this, SLOT(selectFont()));
-
+	
 	/*
 	 * Moving style
 	 * ------------
 	 */
-	QBoxLayout *blm = new QVBoxLayout(gm, 20);
+	QBoxLayout *blm = new QVBoxLayout(gm, nb->spacingHint());
 	
 	blm->addSpacing(gm->fontMetrics().height());
 	
-	QRadioButton *rbn = new QRadioButton(gm);
-	QRadioButton *rbs = new QRadioButton(gm);
-	QRadioButton *rbd = new QRadioButton(gm);
+	for (int i = 0; i < 3; i++)
+		rbMove[i] = new QRadioButton(gm);
 
-	rbn->setText(i18n("&Disable short moves. Only drag'n drop will move."));
-	rbs->setText(i18n("&Single clicks with the left mouse button will\n"
+	rbMove[SHORT_MOVE_NONE]->setText(i18n("&Disable short moves. Only drag'n drop will move."));
+	rbMove[SHORT_MOVE_SINGLE]->setText(i18n("&Single clicks with the left mouse button will\n"
 			  "move a checker the shortest possible distance."));
-	rbd->setText(i18n("D&ouble clicks with the left mouse button will\n"
+	rbMove[SHORT_MOVE_DOUBLE]->setText(i18n("D&ouble clicks with the left mouse button will\n"
 			  "move a checker the shortest possible distance."));
 	
-	rbn->setMinimumSize(rbn->sizeHint());
-	rbs->setMinimumSize(rbs->sizeHint());
-	rbd->setMinimumSize(rbd->sizeHint());
-
-	blm->addWidget(rbn);
-	blm->addWidget(rbs);
-	blm->addWidget(rbd);
-
-	rbn->setChecked(getShortMoveMode() == SHORT_MOVE_NONE);
-	rbs->setChecked(getShortMoveMode() == SHORT_MOVE_SINGLE);
-	rbd->setChecked(getShortMoveMode() == SHORT_MOVE_DOUBLE);
-
-	connect(rbn, SIGNAL(clicked()), this, SLOT(selectMoveNone()));
-	connect(rbs, SIGNAL(clicked()), this, SLOT(selectMoveSingle()));
-	connect(rbd, SIGNAL(clicked()), this, SLOT(selectMoveDouble()));
+	for (int i = 0; i < 3; i++) {
+		rbMove[i]->setMinimumSize(rbMove[i]->sizeHint());
+		blm->addWidget(rbMove[i]);
+		rbMove[i]->setChecked(i == getShortMoveMode());
+	}
 
 	/*
 	 * Other options
@@ -145,67 +228,42 @@ void KBgBoardSetup::getSetupPages(QTabDialog *nb)
 	 */
 	QGridLayout *glo = new QGridLayout(go, 1, 1, 20);
 	
-	cbp = new QCheckBox(i18n("Pic count in the title bar"), go);
+	cbp = new QCheckBox(i18n("Show pip count in title bar"), go);
 	cbp->setChecked(computePipCount);
 	cbp->adjustSize();
 	cbp->setMinimumSize(cbp->size());
 	
 	glo->addRowSpacing(0, cbp->height());
-
-	glo->addWidget(cbp, 0, 0, AlignLeft);
-
-	connect(cbp, SIGNAL(clicked()), this, SLOT(setPipCount()));
-
-	/*
-	 * put in the page
-	 * ===============
-	 */
+	glo->addWidget(cbp, 0, 0);
+	
 	gl->activate();
+	
 	w->adjustSize();
 	w->setMinimumSize(w->size());
-	nb->addTab(w, i18n("&Board"));
+	
+	tc->addTab(w, i18n("&Board"));
 
 	/*
 	 * Save current settings
-	 * =====================
+	 * ---------------------
 	 */
 	saveBackgroundColor = backgroundColor();
 	saveBaseColors[0]   = baseColors[0];
 	saveBaseColors[1]   = baseColors[1];
-	saveFont            = getFont();
-	saveMoveMode        = getShortMoveMode();
-}
 
-/*
- * Set the pip count flag
- */
-void KBgBoardSetup::setPipCount() 
-{
-	computePipCount = cbp->isChecked();
-}
-
-/*
- * Disable short move feature
- */
-void KBgBoardSetup::selectMoveNone() 
-{
-	setShortMoveMode(SHORT_MOVE_NONE);
-}
-
-/*
- * Short moves on single clicks
- */
-void KBgBoardSetup::selectMoveSingle()
-{
-	setShortMoveMode(SHORT_MOVE_SINGLE);
-}
-
-/*
- * Short moves on double clicks
- */
-void KBgBoardSetup::selectMoveDouble()
-{
-	setShortMoveMode(SHORT_MOVE_DOUBLE);
+	/*
+	 * Font selection page
+	 * ===================
+	 */
+	w = new QWidget(tc);
+	kf = new KFontChooser(w);
+	kf->setFont(getFont());
+	gl = new QGridLayout(w, 1, 1, nb->spacingHint());
+	gl->addWidget(kf, 0, 0);
+	gl->activate();
+	w->adjustSize();
+	w->setMinimumSize(w->size());
+	tc->addTab(w, i18n("&Font"));
 }
 
 /*
@@ -217,20 +275,6 @@ KBgBoardSetup::KBgBoardSetup(QWidget *parent, const char *name, QPopupMenu *menu
 	// empty
 }
 
-/*
- * Undo all the changes - i.e. restore settings
- */
-void KBgBoardSetup::undoSetupChanges()
-{
-	setBackgroundColor(saveBackgroundColor);
-	baseColors[0] = saveBaseColors[0];
-	baseColors[1] = saveBaseColors[1];
-	setFont(saveFont);
-	for (int i = 0; i < 30; i++)
-		cells[i]->update();
-	setShortMoveMode(saveMoveMode);
-}
-
 /*
  * User changed first checker color
  */
@@ -279,21 +323,6 @@ void KBgBoardSetup::selectBackgroundColor()
 	delete c;
 }
 
-/*
- * User changed font
- */
-void KBgBoardSetup::selectFont()
-{
-	KFontDialog *c = new KFontDialog(this, "font-dlg", true);
-	c->setFont(getFont());
-	if (c->exec()) {
-		setFont(c->font());
-		for (int i = 0; i < 30; i++)
-			cells[i]->update();
-	}
-	delete c;
-}
-
 /*
  * Saves the persistent settings of the board
  */
@@ -352,15 +381,15 @@ void KBgBoard::setFont(const QFont& f)
  */
 void KBgBoard::queryCube()
 {
-	KBgBoardStatus *st = new KBgBoardStatus();
+	KBgStatus *st = new KBgStatus();
 	getState(st);
 	KBgBoardQCube *dlg = 
-		new KBgBoardQCube(abs(st->getCube()), (st->getCube(US) > 0), (st->getCube(THEM) > 0));
+		new KBgBoardQCube(abs(st->cube()), (st->cube(US) > 0), (st->cube(THEM) > 0));
 	if (dlg->exec()) {
 		bool u = ((dlg->getCubeValue() == 0) || (dlg->getCubeOwner() == US  ));
 		bool t = ((dlg->getCubeValue() == 0) || (dlg->getCubeOwner() == THEM));
-		st->setCube((int)rint(pow(2, dlg->getCubeValue())), u, t);
-		setState(st);
+		st->setCube((int)rint(pow(2.0, dlg->getCubeValue())), u, t);
+		setState(*st); // JENS
 	}
 	delete dlg;
 	delete st;
@@ -620,10 +649,10 @@ bool KBgBoard::getEditMode() const
 }
 
 /*
- * This function takes a BoardStatus object and fills it with the current
+ * This function takes a KBgStatus object and fills it with the current
  * board status.
  */
-KBgBoardStatus* KBgBoard::getState(KBgBoardStatus *st) const
+KBgStatus* KBgBoard::getState(KBgStatus *st) const
 {
 	st->setColor(color);
 	st->setDirection(direction);
@@ -962,11 +991,10 @@ void KBgBoardCell::drawCube(QPainter *p, int who, int xo, int yo,
 	cubeNum.setNum(v);
 
 	/*
-	 * Adjust the font with the size of the checkers
+	 * Adjust the font size
 	 */
 	QFont f = board->getFont();
-	int size = int(0.7*r.width());
-	f.setPointSize((size <= 0) ? 1 : size);
+	f.setPointSizeFloat(0.75*f.pointSizeFloat());
 	p->setFont(f);
 	p->drawText(r, AlignCenter, cubeNum);      
 }
@@ -1327,13 +1355,13 @@ void KBgBoardHome::mouseDoubleClickEvent(QMouseEvent * e)
 
 					KBgBoardQDice *dlg = new KBgBoardQDice();
 					if (dlg->exec()) {
-						KBgBoardStatus *st = new KBgBoardStatus();
+						KBgStatus *st = new KBgStatus();
 						board->getState(st);
 						st->setDice(w, 0, dlg->getDice(0));
 						st->setDice(w, 1, dlg->getDice(1));
 						st->setDice(((w == US) ? THEM : US), 0, 0);
 						st->setDice(((w == US) ? THEM : US), 1, 0);
-						board->setState(st);
+						board->setState(*st); // JENS
 						delete st;
 					}
 					delete dlg;
@@ -1572,196 +1600,6 @@ void KBgBoardCell::mouseReleaseEvent(QMouseEvent *e)
  	}
 }
 
-/*
- * This is the constructor of the board status class. It initializes the
- * status to an empty board with cube 1 and empty dice.
- */
-KBgBoardStatus::KBgBoardStatus()
-{
-	for (int i = 0; i < 26; ++i)
-		setBoard(i, US, 0);
-
-	setCube(1, true, true);
-
-	setDice(US  , 0, 0);
-	setDice(US  , 1, 0);
-	setDice(THEM, 0, 0);
-	setDice(THEM, 1, 0);
-
-	setHome(US  , 0);
-	setHome(THEM, 0);
-
-	setBar(US  , 0);
-	setBar(THEM, 0);
-	
-	setColor(1, US);
-	setDirection(1);
-}
-
-/*
- * This is the destructor of the board status class. 
- * It doesn't do anything.
- */
-KBgBoardStatus::~KBgBoardStatus()
-{
-	// nothing
-}
-
-/*
- * This function sets the dice of a status object. It takes the parameters
- * w (who - US or THEM), n (dice number - 0 or 1) and v (value). 
- */
-void KBgBoardStatus::setDice(const int& w, const int& n, const int& v)
-{
-	if ((w == US || w == THEM) && (n == 0 || n == 1)) {
-		if (0 <= v && v <= 6)
-			dice[w][n] = v;
-		else
-			dice[w][n] = 0;
-	}
-}
-
-/*
- * This function returns the n-th dice for the player w from the status object.
- */
-int KBgBoardStatus::getDice(const int& w, const int& n) const
-{
-	if ((w == US || w == THEM) && (n == 0 || n == 1))
-		return dice[w][n];
-	else 
-		return 0;
-}
-
-/*
- * This function sets the direction of the board. A negative d indicates that
- * player US plays from 24 to 1, a positive d indicates that US plays from
- * 1 to 24.
- */
-void KBgBoardStatus::setDirection(const int& d)
-{
-	direction = ((d < 0) ? -1 : +1);
-}
-
-/*
- * This function returns the current direction of the status.
- */
-int KBgBoardStatus::getDirection() const
-{
-	return direction;
-}
-
-/*
- * This function sets the number of checkers on the home of user w to v.
- */
-void KBgBoardStatus::setHome(const int& w, const int& v)
-{
-	if (w == US)
-		home[w] =  abs(v);
-	else if (w == THEM)
-		home[w] = -abs(v);		
-}
-
-/*
- * This function returns the number of checkers on the home of player w.
- * The returned number may be positive or negative - the board handles 
- * this.
- */
-int KBgBoardStatus::getHome(const int& w) const
-{
-	return ((w == US || w == THEM) ? color*home[w] : 0);
-}
-
-/*
- * This function sets the number of checkers on the bar of user w to v.
- */
-void KBgBoardStatus::setBar(const int& w, const int& v)
-{
-	if (w == US)
-		bar[w] =  abs(v);
-	else if (w == THEM)
-		bar[w] = -abs(v);
-}
-
-/*
- * This function returns the number of checkers on the bar of player w.
- * The returned number may be positive or negative - the board handles 
- * this.
- */
-int KBgBoardStatus::getBar(const int& w) const
-{
-	return ((w == US || w == THEM) ? color*bar[w] : 0);
-}
-
-/*
- * This function sets the cube to the value c (note that c must be a legal
- * value, i.e. a power of 2). The other two parameters indicate who may
- * double the cube.
- */
-void KBgBoardStatus::setCube(const int& c, const bool& us, const bool& them)
-{
-	if (c==1 || c==2 || c==4 || c==8 || c==16 || c==32 || c==64)
-		cube = c;
-	maydouble[US  ] =   us;
-	maydouble[THEM] = them;
-}
-
-/*
- * This function returns the cube value. Note that the return value is
- * positive iff the user w (default US) may double and negative values
- * indicate that the user may not double.
- */
-int KBgBoardStatus::getCube(const int& w) const
-{
-	if (w == US || w == THEM)
-		return ((maydouble[w]) ? cube : -cube);
-	return 0;
-}
-
-/*
- * This function puts v checkers of player w on the i-th field.
- */
-void KBgBoardStatus::setBoard(int i, int w, int v)
-{
-	if (0 < i && i < 25) {
-		if (w == US)
-			board[i] =  abs(v);
-		else if (w == THEM)
-			board[i] = -abs(v);
-	}
-}
-
-/*
- * This function returns the number of checkers (positive or negative
- * depending on the color) of the i-th field.
- */
-int KBgBoardStatus::getBoard(const int& i) const
-{
-	return ((0 < i && i < 25) ? color*board[i] : 0);
-}
-
-/*
- * This function sets the color of player w to col. This may be either
- * positive or negative.
- */
-void KBgBoardStatus::setColor(const int& col, const int& w)
-{
-	if (w == US)
-		color =  ((col < 0) ? -1 : +1);
-	else if (w == THEM)
-		color = -((col < 0) ? -1 : +1);
-}
-
-/*
- * This function returns the color of the player w.
- */
-int KBgBoardStatus::getColor(const int& w) const
-{
-	if (w == THEM)
-		return -color;
-	else
-		return  color;
-}
-
 /*
  * This is the destructor of the home cells. It doesn't do anything.
  */
@@ -2261,34 +2099,34 @@ bool KBgBoard::diceAllowMove(int src, int dest)
 
 /*
  * This is the most important of all members of the board class. It takes
- * a single board status object initializes the internal status accordingly.
+ * a single board status object and initializes the internal status.
  */
-void KBgBoard::setState(const KBgBoardStatus* st)
+void KBgBoard::setState(const KBgStatus &st)
 {
-	color     = st->getColor();
-	direction = st->getDirection();
+	color     = st.color();
+	direction = st.direction();
 	
-	cubechanged = (cube != abs(st->getCube()));
-	cube        = abs(st->getCube());
-	maydouble[US  ] = (st->getCube(US  ) > 0);
-	maydouble[THEM] = (st->getCube(THEM) > 0);
+	cubechanged = (cube != abs(st.cube()));
+	cube        = abs(st.cube());
+	maydouble[US  ] = (st.cube(US  ) > 0);
+	maydouble[THEM] = (st.cube(THEM) > 0);
 
 	for (int i = 0; i < 30; i++)
 		cells[i]->statusUpdate(direction, color); 
 
 	for (int i = 1; i < 25; ++i)
-		board[i] = st->getBoard(i);
+		board[i] = st.board(i);
 		
-	onbar[US  ] = st->getBar(US  );
-	onbar[THEM] = st->getBar(THEM);
+	onbar[US  ] = st.bar(US  );
+	onbar[THEM] = st.bar(THEM);
 	
-	onhome[US]   = st->getHome(US  );
-	onhome[THEM] = st->getHome(THEM);
+	onhome[US]   = st.home(US  );
+	onhome[THEM] = st.home(THEM);
 	
-	dice[US  ][0]    = st->getDice(US  , 0);
-	dice[US  ][1]    = st->getDice(US  , 1);
-	dice[THEM][0]    = st->getDice(THEM, 0);
-	dice[THEM][1]    = st->getDice(THEM, 1);
+	dice[US  ][0]    = st.dice(US  , 0);
+	dice[US  ][1]    = st.dice(US  , 1);
+	dice[THEM][0]    = st.dice(THEM, 0);
+	dice[THEM][1]    = st.dice(THEM, 1);
 	
 	for (int i = 0; i < 7; ++i)
 		possMoves[i] = 0;
@@ -2309,13 +2147,13 @@ void KBgBoard::setState(const KBgBoardStatus* st)
 	for (int i=1; i<25; ++i)
 		(getCell(i))->cellUpdate(board[i]);
 
-	(getCell(BAR_US  ))->cellUpdate(st->getBar(US  ), cubechanged);
-	(getCell(BAR_THEM))->cellUpdate(st->getBar(THEM), cubechanged);
+	(getCell(BAR_US  ))->cellUpdate(st.bar(US  ), cubechanged);
+	(getCell(BAR_THEM))->cellUpdate(st.bar(THEM), cubechanged);
 
-	(getCell(HOME_US_LEFT   ))->cellUpdate(st->getHome(US  ), cubechanged);
-	(getCell(HOME_US_RIGHT  ))->cellUpdate(st->getHome(US  ), cubechanged);
-	(getCell(HOME_THEM_LEFT ))->cellUpdate(st->getHome(THEM), cubechanged);
-	(getCell(HOME_THEM_RIGHT))->cellUpdate(st->getHome(THEM), cubechanged);
+	(getCell(HOME_US_LEFT   ))->cellUpdate(st.home(US  ), cubechanged);
+	(getCell(HOME_US_RIGHT  ))->cellUpdate(st.home(US  ), cubechanged);
+	(getCell(HOME_THEM_LEFT ))->cellUpdate(st.home(THEM), cubechanged);
+	(getCell(HOME_THEM_RIGHT))->cellUpdate(st.home(THEM), cubechanged);
 
 	moveHistory.clear();
 	redoHistory.clear();
@@ -2543,15 +2381,9 @@ void KBgBoardField::paintCell(QPainter *p, int xo, int yo, double sf) const
 	QString t;
 	t.setNum(getNumber());
 
-	/*
-	 * Adjust the font with the size of the checkers
-	 */
-	QFont f = board->getFont();
-	int size = int(0.7*getCheckerDiameter());
-	f.setPointSize((size <= 0) ? 1 : size);
-	p->setFont(f);
-	p->drawText(xo, yo+sf*((cellID < 13) ? 0 : height()-int(1.3*(double)f.pointSize())),
-		    width()*sf, int(1.2*(double)f.pointSize()*sf), AlignCenter, t);
+	p->setFont(board->getFont());
+	p->drawText(xo, yo+sf*((cellID < 13) ? 5 : height()-5-p->font().pointSize()),
+		    width()*sf, p->font().pointSize()*sf, AlignCenter, t);
 	
 	/*
 	 * Put the checkers on the field.
@@ -3003,7 +2835,7 @@ void KBgBoard::getRollDice(const int w)
  * This is the constructor of the KBgBoard class. It creates
  * a backgammon board with an initial distribution of checkers, empty 
  * dice and a cube with face value 1. The initial board is not usable!
- * You have to change the status by passing a KBgBoardStatus
+ * You have to change the status by passing a KBgStatus
  * object to setState(...) before you can play!
  */
 KBgBoard::KBgBoard(QWidget *parent, const char *name, QPopupMenu *menu)
@@ -3051,7 +2883,7 @@ KBgBoard::KBgBoard(QWidget *parent, const char *name, QPopupMenu *menu)
 	 * Get the default seeting of the board and initialize the
 	 * state of it.
 	 */
-	KBgBoardStatus *st = new KBgBoardStatus();
+	KBgStatus *st = new KBgStatus();
 
 	st->setCube(1, true, true);
 	st->setDirection(+1);
@@ -3067,7 +2899,7 @@ KBgBoard::KBgBoard(QWidget *parent, const char *name, QPopupMenu *menu)
 	st->setDice(US  , 0, 0); st->setDice(US  , 1, 0);
 	st->setDice(THEM, 0, 0); st->setDice(THEM, 1, 0);
 
-	setState(st);
+	setState(*st);
 
 	delete st;
 	
