@@ -1,5 +1,6 @@
-/*
-  Copyright (C) 1999,2000 Jens Hoefkens
+/* Yo Emacs, this -*- C++ -*-
+
+  Copyright (C) 1999-2001 Jens Hoefkens
   jens@hoefkens.com
   
   This program is free software; you can redistribute it and/or modify
@@ -38,7 +39,6 @@
 #include <config.h>
 #endif 
 
-
 #include <qspinbox.h>
 #include <qpushbutton.h>
 #include <qcheckbox.h>
@@ -48,6 +48,7 @@
 #include <qpixmap.h>
 #include <qbitmap.h>
 #include <qregexp.h>
+#include <qradiobutton.h>
 #include <qwidget.h>
 #include <qlist.h>
 #include <qtimer.h>
@@ -55,17 +56,18 @@
 #include <qcursor.h>
 #include <qpopupmenu.h> 
 #include <qcombobox.h> 
-#include <qtabdialog.h>
+#include <kdialogbase.h>
+#include <kfontdialog.h>
 
+#include "kbgstatus.h"
 
 /*
  * Just some internal constants and classes
  */
-const int US               =   0;
-const int THEM             =   1;
-const int BOTH             =   2;
-const int CUBE_UPPER       =   2;
-const int CUBE_LOWER       =   3;
+const int US   = KBgStatus::US;
+const int THEM = KBgStatus::THEM;
+const int BOTH = KBgStatus::BOTH;
+
 const int HOME_US_LEFT     = 101;
 const int HOME_US_RIGHT    = 102;
 const int HOME_THEM_LEFT   = 103;
@@ -80,7 +82,6 @@ const int SHORT_MOVE_SINGLE = 1;
 const int SHORT_MOVE_DOUBLE = 2;
 
 class KBgBoard;
-class KBgBoardStatus;
 class KBgBoardCell;
 class KBgBoardMove;
 class KBgBoardHome;
@@ -88,126 +89,6 @@ class KBgBoardBar;
 class KBgBoardField;
 class KBgBoardQDice;
 
-/**
- * This is a "public" class. It is used to initialize the
- * backgammon board. 
- *
- * The names of the members should be rather self-explaining.
- */
-class KBgBoardStatus
-{
- public:
-
-	/**
-	 * The constructor intializes the status
-	 * to an "empty" state. The board is basically
-	 * undefined in this state and should never be 
-	 * passed as a parameter to the board.
-	 */
-	KBgBoardStatus();
-
-	/**
-	 * The "standard" destructor. What can I say...
-	 */
-	virtual ~KBgBoardStatus();
-
-	/**
-	 * Puts v checkers of player w on the i-th field.
-	 * The player is either US or THEM. The number v
-	 * should be positive or 0. All fields are initialized
-	 * to 0 and hence only the non-zero ones need init.
-	 */
-	void setBoard(int i, int w, int v);
-
-	/**
-	 * Returns the number of checkers on the i-th field. This
-	 * number may be positive or negative depending on the 
-	 * color of the checkers.
-	 */
-	int getBoard(const int& i) const;
-
-	/**
-	 * Sets the color of player w to col. This may be either
-	 * positive or negative 1.
-	 */
-	void setColor(const int& col, const int& w = US);
-
-	/**
-	 * Returns the current color of player w.
-	 * The result will be plus or minus 1.
-	 */
-	int getColor(const int& w = US) const;
-	
-	/**
-	 * Set the cube to the value c (note that c must be a legal
-	 * value, i.e. a power of 2). The other two parameters indicate 
-	 * who may double the cube.
-	 */
-	void setCube(const int& c, const bool& us, const bool& them);
-
-	/**
-	 * This function returns the cube value. Note that the return value is
-	 * positive iff the user w (default US) may double and negative values
-	 * indicate that the user may not double.
-	 */
-	int getCube(const int& w = US) const;
-	
-	/**
-	 * Set the number of checkers on the home of user
-	 * w to v.
-	 */
-	void setHome(const int& w = US, const int& v = 0);
-
-	/**
-	 * Get the number of checkers on the home of player w.
-	 */
-	int getHome(const int& w = US) const;
-	
-	/**
-	 * Set the number of checkers on the bar of user w to v.
-	 */
-	void setBar(const int& w = US, const int& v = 0);
-
-	/**
-	 * Get the number of checkers on the bar of player w.
-	 */
-	int getBar(const int& w = US) const;
-	
-	/**
-	 * This function sets the direction of the board. A negative d 
-	 * indicates that player US plays from 24 to 1, a positive d 
-	 * indicates that US plays from 1 to 24.
-	 */
-	void setDirection(const int& d);
-
-	/**
-	 * Returns the current direction of the game
-	 */
-	int getDirection() const;
-
-	/**
-	 * Set the n-th die (0, 1) of player w (US, THEM) to v.
-	 */
-	void setDice(const int& w, const int& n, const int& v);
-
-	/**
-	 * Get the n-th die of player w.
-	 */
-	int getDice(const int& w, const int& n) const;
-	
- private:
-
-	int board[26];
-	int home[2];
-	int bar[2];
-	int dice[2][2];
-
-	int cube;
-	int direction;
-	int color;
-
-	bool maydouble[2];
-};
 
 /**
  * The KBgBoard class.
@@ -327,7 +208,7 @@ public slots:
 	 * a board status - s. the KBgBoardStatus class - 
 	 * and sets the board accordingly.
 	 */
-	void setState(const KBgBoardStatus* st);
+	void setState(const KBgStatus &);
 
 	/**
 	 * Set the context menu
@@ -337,7 +218,7 @@ public slots:
 	/**
 	 * Get the current state of the board.
 	 */
-	KBgBoardStatus *getState(KBgBoardStatus *st) const;
+	KBgStatus *getState(KBgStatus *st) const;
 
 	/**
 	 * Sets the edit mode of the board. In that mode the board can be
@@ -363,6 +244,12 @@ public slots:
 
  signals:	
 
+	/**
+	 * The text identifies the current game status - could be put
+	 * into the main window caption
+	 */
+	void statText(const QString &msg);
+	
 	/**
 	 * The cells connect to this signal and it tells them that it is
 	 * time to update their content now if necessary.
@@ -1016,15 +903,24 @@ public:
 	/**
 	 * Lets the board put its setup pages into the notebook nb
 	 */
-	void getSetupPages(QTabDialog *nb);
+	void getSetupPages(KDialogBase *nb);
 
 public slots:
 
         /**
-	 * Setup changes are written to disk and can be undone by
-	 * caling this slot.
+	 * Setup changes are confirmed. Store them.
 	 */
-	void undoSetupChanges();
+	void setupOk();
+
+	/**
+	 * Setup has been cancelled. Undo the color changes
+	 */
+	void setupCancel();
+
+	/**
+	 * Load default values for user settings
+	 */
+	void setupDefault();
 
 protected slots:
 
@@ -1043,40 +939,17 @@ protected slots:
 	 */	
 	void selectBaseColorTwo();
 
-	/** 
-	 * Set the status of the pip count flag
-	 */
-	void setPipCount();
-
-        /**
-	 * Open a font dialog
-	 */	
-	void selectFont();
-
-	/**
-	 * User selected move-move radio button: none
-	 */
-        void selectMoveNone();
-
-	/**
-	 * User selected move-move radio button: single
-	 */
-	void selectMoveSingle();
-
-	/**
-	 * User selected move-move radio button: double
-	 */
-	void selectMoveDouble();
-
 private:
 
 	/**
 	 * Save settings before the user changed them
 	 */
-	QFont saveFont;
+	KFontChooser *kf;
+
+	QRadioButton *rbMove[3];
+
 	QColor saveBackgroundColor;
 	QColor saveBaseColors[2];
-	int saveMoveMode;
 
 	/**
 	 * Need these to change their colors
