@@ -2,11 +2,11 @@
 // KBlackbox
 //
 // A simple game inspired by an emacs module
-// 
+//
 // File: main.cpp
 //
 // The main() function
-// 
+//
 
 
 #include <kapp.h>
@@ -21,22 +21,21 @@
 static const char *description = I18N_NOOP("KDE Blackbox Game");
 
 /*
-  The program starts here. 
+  The program starts here.
 */
 
 int main( int argc, char **argv )
 {
-  KAboutData aboutData( "kblackbox", I18N_NOOP("KBlackBox"), 
-    KBVERSION, description, KAboutData::License_GPL, 
+  KAboutData aboutData( "kblackbox", I18N_NOOP("KBlackBox"),
+    KBVERSION, description, KAboutData::License_GPL,
     "(c) 1999-2000, Robert Cimrman");
   aboutData.addAuthor("Robert Cimrman",0, "cimrman3@students.zcu.cz");
   KCmdLineArgs::init( argc, argv, &aboutData );
 
   KApplication a;
-  KBBGame v;
-  
-  a.setMainWidget( &v );
-  debug( "Thank you for running KBlackBox, version %s.", KBVERSION );
-  v.show();
+  KBBGame *v = new KBBGame;
+
+  a.setMainWidget( v );
+  v->show();
   return a.exec();
 }
