@@ -20,7 +20,7 @@
 // QT includes
 #include <qpushbutton.h>
 #include <qlabel.h>
-#include <qpopupmenu.h>
+//#include <qpopupmenu.h>
 #include <qtimer.h>
 #include <qpainter.h>
 #include <qtooltip.h>
@@ -280,9 +280,9 @@ else if (getStatus() == statContinueBet || getStatus() == statContinueRaise) {
 		betBox->setEnabled(true);
 		betBox->beginRaise();
 		if (adjust)
-			emit statusBarMessage("Clicking on draw will mean you adjust your bet");
+			emit statusBarMessage(i18n("Clicking on draw means you adjust your bet"));
 		else
-			emit statusBarMessage("Clicking on draw will mean you are out");
+			emit statusBarMessage(i18n("Clicking on draw means you are out"));
 	}
 	else {
 		if (getStatus() == statBet)
@@ -442,6 +442,9 @@ void kpok::initPoker(int players, Player* ownAllPlayers)
 // finally clear the pot and show the decks/cash - in one word: begin :-)
  pot = 0;
  drawAllDecks();
+ for (int unsigned i = 0; i < player.count(); i++) {
+	playerBox[i]->repaintCard();
+ }
  paintCash();
  playerBox[0]->setHeldEnabled(false);
 
@@ -791,32 +794,40 @@ void kpok::paintEvent( QPaintEvent *)
       return;
    }
 
-   QString t;
-   t = wonLabel->text();
+   QString t = wonLabel->text();
+   wonLabel->hide();
 
    static int sin_tbl[16] = {
       0, 38, 71, 92, 100, 92, 71, 38,  0, -38, -71, -92, -100, -92, -71, -38};
 
-   if ( t.isEmpty() )
+   if ( t.isEmpty() ) {
       return;
+   }
 
-
-   QFont wonFont("Helvetica", 18, QFont::Bold);
+   QFont wonFont;
+   wonFont.setPointSize(18);
+   wonFont.setBold(true);
 
    QFontMetrics fm = QFontMetrics(wonFont);
 
    int w = fm.width(t) + 20;
    int h = fm.height() * 2;
+   while (w > mWonWidget->width() && wonFont.pointSize() > 6) {// > 6 for emergency abort...
+   	wonFont.setPointSize(wonFont.pointSize() - 1);
+   	fm = QFontMetrics(wonFont);
+	w = fm.width(t) + 20;
+   	h = fm.height() * 2;
+   }
 
-   int pmx = this->width() / 2 - w / 2;
-//   int pmy = wonLabelVDist - h / 4;
-   int pmy = (playerBox[0]->x() + playerBox[0]->height() + 10) - h / 4;
+   int pmx = mWonWidget->width() / 2 - w / 2;
+   int pmy = 0;
+//   int pmy = (playerBox[0]->x() + playerBox[0]->height() + 10) - h / 4;
 
    QPixmap pm( w, h );
-   pm.fill( this, pmx, pmy );
+   pm.fill( mWonWidget, pmx, pmy );
 
    if (fCount == -1) { /* clear area */
-      bitBlt( this, pmx, pmy, &pm );
+      bitBlt( mWonWidget, pmx, pmy, &pm );
       return;
    }
 
@@ -838,7 +849,7 @@ void kpok::paintEvent( QPaintEvent *)
    p.end();
 
 // 4: Copy the pixmap to the Hello widget
-   bitBlt( this, pmx, pmy, &pm );
+   bitBlt( mWonWidget, pmx, pmy, &pm );
 
 }
 
