@@ -68,6 +68,7 @@ StoneField::StoneField(int width, int height,
     maxstone=sizex*sizey;
     field=new Stone[maxstone];
     newGame(board,colors);
+    m_gotBonus= false;
 }
 
 StoneField::~StoneField() {
@@ -283,7 +284,10 @@ StoneField::remove(int x,int y,bool force) {
 	}
 	
 	// add a bonus, if field is empty
-	if (!field[map(0, sizey-1)].color) score+=1000;
+	if (!field[map(0, sizey-1)].color) {
+		score+=1000;
+		m_gotBonus= true;
+	}
 	
 	// gameover is undefined
 	gameover=-1;
@@ -345,6 +349,10 @@ StoneField::isGameover() const {
      return (bool)gameover;
 }
 
+bool StoneField::gotBonus() const {
+	return m_gotBonus;
+}
+
 int
 StoneField::getBoard() const {
      return board;
