@@ -3,23 +3,25 @@
 
 #include <qstring.h>
 #include <qbuffer.h>
+
 #include "miscui.h"
 
+
 /** Internal class : used for client identification. */
 class cId
 {
  public:
 	cId() {}
 	cId(const QString &gameName, const QString &gameId);
-	
+
 	enum State { Accepted, LibIdClash, GameNameClash, GameIdClash };
 	void check(const cId &id);
 	bool accepted() const { return state==Accepted; }
 	QString errorMessage(const cId &id) const;
-	
+
 	friend QDataStream &operator << (QDataStream &s, const cId &id);
 	friend QDataStream &operator >> (QDataStream &s, cId &id);
-	
+
  private:
 	QString libId, gameName, gameId;
 	State   state;
@@ -54,8 +56,6 @@ QDataStream &operator << (QDataStream &s, const MeetingCheckBox::Type &t);
 QDataStream &operator >> (QDataStream &s, MeetingCheckBox::Type &t);
 QDataStream &operator << (QDataStream &s, const TypeInfo &ti);
 QDataStream &operator >> (QDataStream &s, TypeInfo &ti);
-//QDataStream &operator << (QDataStream &s, const PlayerCheckBox::Type &t);
-//QDataStream &operator >> (QDataStream &s, PlayerCheckBox::Type &t);
 
 /* Internal class : store game data. */
 class BoardData
@@ -64,7 +64,7 @@ class BoardData
 	BoardData() {}
 
 	QString              name;
-	PlayerCheckBox::Type type;
+	PlayerComboBox::Type type;
 };
 QDataStream &operator <<(QDataStream &, const BoardData &);
 QDataStream &operator >>(QDataStream &, BoardData &);
@@ -77,7 +77,7 @@ class ExtData
 	ExtData(const QValueList<BoardData> &_bds, const QString &_text,
 			MeetingCheckBox::Type _type)
 	: bds(_bds), text(_text), type(_type) {}
-	
+
 	QValueList<BoardData> bds;
 	QString               text;
 	MeetingCheckBox::Type type;
@@ -90,7 +90,7 @@ class MeetingLineData
 {
  public:
 	MeetingLineData() {}
-	
+
 	ExtData ed;
 	bool own;
 };
@@ -98,13 +98,15 @@ QDataStream &operator << (QDataStream &s, const MeetingLineData &pld);
 QDataStream &operator >> (QDataStream &s, MeetingLineData &pld);
 
 /* Internal class : store remote host data. */
+class Socket;
+
 class RemoteHostData
 {
  public:
-	RemoteHostData() {}
-	
-	int                   socket;
-	QValueList<BoardData> bds;
+	RemoteHostData() : socket(0) {}
+
+	Socket                *socket;
+	QValueList<BoardData>  bds;
 };
 
 /* Internal class : store connection data (used by config. wizard). */
@@ -112,9 +114,8 @@ class ConnectionData
 {
  public:
 	ConnectionData() {}
-	
+
 	bool           network, server;
-	QString        serverName, serverAddress, hostName, hostAddress;
 	RemoteHostData rhd;
 };
 
@@ -128,16 +129,16 @@ class Stream : public QDataStream
 {
  public:
 	Stream(int mode);
-	
+
 	void clear();
 	void setArray(QByteArray a);
-	
+
 	QByteArray buffer() const { return buf.buffer(); }
 	uint size() const { return buf.buffer().size(); }
 
  protected:
 	QBuffer buf;
-	
+
  private:
 	int mode;
 };
@@ -164,9 +165,9 @@ class IOBuffer
 {
  public:
 	IOBuffer() {}
-	
+
 	void writingToReading();
-	
+
 	ReadingStream reading;
 	WritingStream writing;
 };
@@ -178,15 +179,15 @@ class BufferArray
 	BufferArray() {}
 	BufferArray(uint nb) { resize(nb); }
 	~BufferArray();
-	
+
 	void resize(uint nb);
-	
+
 	uint size() const { return a.size(); }
 	IOBuffer *operator [](uint i) const { return a[i]; }
-	
+
  private:
 	QArray<IOBuffer *> a;
-	
+
 	void clear(uint nb);
 };
 QDataStream &operator <<(QDataStream &s, const BufferArray &b);
