@@ -1,5 +1,8 @@
 #include "wizard.h"
 
+#include <sys/types.h>
+#include <netinet/in.h>
+
 #include <qvbuttongroup.h>
 #include <qradiobutton.h>
 #include <qhbox.h>
@@ -14,9 +17,18 @@
 #include <kmessagebox.h>
 #include <kdialogbase.h>
 
-#include "netutils.h"
 #include "types.h"
 #include "defines.h"
+#include "socket.h"
+
+#ifdef __bsdi__
+#define IPPORT_USERRESERVED IPPORT_DYNAMIC
+#endif
+#if defined(__NetBSD__) || defined(__sgi)
+#define IPPORT_USERRESERVED IPPORT_RESERVED
+#endif
+#define MIN_USER_PORT (unsigned short int)IPPORT_USERRESERVED
+#define MAX_USER_PORT 65535
 
 MPWizard::MPWizard(const MPGameInfo &gi, ConnectionData &_cd,
 				   QWidget *parent, const char *name)
@@ -34,7 +46,7 @@ void MPWizard::setupTypePage()
 {
 	typePage = new QVBox(this);
 	typePage->setMargin(KDialogBase::marginHint());
-	
+
 	QVButtonGroup *vbg = new QVButtonGroup(typePage);
 	connect(vbg, SIGNAL(clicked(int)), SLOT(typeChanged(int)));
 	QRadioButton *b;
@@ -55,7 +67,7 @@ void MPWizard::setupTypePage()
 	int p = kconf->readNumEntry(MP_PORT, (uint)MIN_USER_PORT);
 	eport = new KIntNumInput(p, grid);
         eport->setRange(MIN_USER_PORT, MAX_USER_PORT, 1, false);
-	
+
 	addPage(typePage, i18n("Choose game type"));
 	setHelpEnabled(typePage, FALSE);
 	typeChanged(type);
@@ -66,24 +78,25 @@ void MPWizard::setupLocalPage(const MPGameInfo &gi)
 {
 	localPage = new QVBox(this);
 	localPage->setMargin(KDialogBase::marginHint());
-	
+
 	wl = new WidgetList<PlayerLine>(5, localPage);
 	QSignalMapper *husm = new QSignalMapper(this);
 	if (gi.humanSettingSlot) connect(husm, SIGNAL(mapped(int)),
 									 gi.humanSettingSlot);
 	QSignalMapper *aism = new QSignalMapper(this);
 	if (gi.AISettingSlot) connect(aism, SIGNAL(mapped(int)), gi.AISettingSlot);
-	
+
 	QString n;
-	PlayerCheckBox::Type type;
+	PlayerComboBox::Type type;
 	PlayerLine *pl;
 	ASSERT( gi.maxNbLocalPlayers>0 );
 	for (uint i=0; i<gi.maxNbLocalPlayers; i++) {
-		type = (PlayerCheckBox::Type)
+		type = (PlayerComboBox::Type)
 			kconf->readNumEntry(QString(MP_PLAYER_TYPE).arg(i),
-								PlayerCheckBox::Empty);
+   			            (i==0 ? PlayerComboBox::Human : PlayerComboBox::None));
 		n = kconf->readEntry(QString(MP_PLAYER_NAME).arg(i),
-							 i18n("Player %1").arg(i));
+                             i18n("Player #%1").arg(i));
+
 		pl = new PlayerLine(type, n, gi.humanSettingSlot, gi.AISettingSlot,
 							i!=0, gi.AIAllowed, wl);
 		connect(pl, SIGNAL(typeChanged(int)), SLOT(lineTypeChanged(int)));
@@ -93,12 +106,12 @@ void MPWizard::setupLocalPage(const MPGameInfo &gi)
 		connect(pl, SIGNAL(setAI()), aism, SLOT(map()));
 		wl->append(pl);
 	}
-	
+
 	((QVBox *)localPage)->setSpacing(KDialogBase::spacingHint());
-//	QHBox *hb = new QHBox(localPage);
+
 	keys = new QPushButton(i18n("Configure keys"), localPage);
 	connect(keys, SIGNAL(clicked()), SLOT(configureKeysSlot()));
-	
+
 	addPage(localPage, i18n("Local players settings"));
 	setHelpEnabled(localPage, FALSE);
 	lineTypeChanged(0);
@@ -114,13 +127,14 @@ QString MPWizard::name(uint i) const
 void MPWizard::typeChanged(int t)
 {
 	type = (Type)t;
-	
+
 	QString str;
 	if ( type!=Client ) {
-		if ( !getHostname(str) ) str = "";
+		str = "localhost";
 		lserver->setText(i18n("Hostname"));
 	} else {
-		str = kconf->readEntry(MP_SERVER_ADDRESS, "pc.kde.org");
+		str = kconf->readEntry(MP_SERVER_ADDRESS,
+                               I18N_NOOP("the.server.address"));
 		lserver->setText(i18n("Server address"));
 	}
 	eserver->setText(str);
@@ -133,7 +147,7 @@ void MPWizard::lineTypeChanged(int)
 {
 	bool b = FALSE;
 	for (uint i=0; i<wl->size(); i++)
-		if ( wl->widget(i)->type()==PlayerCheckBox::Human ) {
+		if ( wl->widget(i)->type()==PlayerComboBox::Human ) {
 			b = TRUE;
 			break;
 		}
@@ -143,57 +157,57 @@ void MPWizard::lineTypeChanged(int)
 void MPWizard::accept()
 {
 	kconf->setGroup(MP_GROUP);
-	
+
 	cd.network         = ( type!=Local );
 	cd.server          = ( type!=Client );
-	BoardData bd;
+
+	if (cd.network) {
+        //**********************************************************
+        // create socket
+        int flags = KExtendedSocket::inetSocket
+                    | KExtendedSocket::streamSocket;
+        if (cd.server) flags |= KExtendedSocket::passiveSocket;
+        QString host = QFile::encodeName(eserver->text());
+        KExtendedSocket *socket
+            = new KExtendedSocket(host, eport->value(), flags);
+
+        // do lookup
+        int res = socket->lookup();
+        if ( checkSocket(res, socket, i18n("Error looking up for \"%1\"")
+                         .arg(host), this) ) {
+            delete socket;
+            return;
+        }
+
+        // connect (client) or listen (server)
+        res = (cd.server ? socket->listen() : socket->connect());
+        if ( checkSocket(res, socket, i18n("Error opening socket"), this) ) {
+            delete socket;
+            return;
+        }
+
+        cd.rhd.socket = new Socket(socket, true);
+
+		if ( !cd.server )
+            kconf->writeEntry(MP_SERVER_ADDRESS, eserver->text());
+		kconf->writeEntry(MP_PORT, eport->value());
+	}
+
+    BoardData bd;
 	for (uint i=0; i<wl->size(); i++) {
-		if ( wl->widget(i)->type()==PlayerCheckBox::Empty ) continue;
+		if ( wl->widget(i)->type()==PlayerComboBox::None ) continue;
 		bd.name = name(i);
 		bd.type = wl->widget(i)->type();
 		cd.rhd.bds += bd;
 	}
-	
-	if (cd.network) {
-		QString serror;
-		/* compute addresses */
-		if ( !getInetAddresses(QFile::encodeName(eserver->text()), cd.serverAddress,
-							   cd.serverName, &serror) )
-			R_ERROR_BOX((cd.server ? i18n("Host error")
-						 : i18n("Server error")), serror);
 
-		if (!cd.server) {
-			QString str;
-			if ( !getHostname(str, &serror) ||
-				 !getInetAddresses(QFile::encodeName(str), cd.hostAddress, cd.hostName, &serror) )
-				R_ERROR_BOX(i18n("Hostname error"), serror);
-		}
-
-		/* create a socket */
-		if ( !createInetSocket(cd.rhd.socket, &serror) )
-			R_ERROR_BOX(serror, QString::null);
-
-		/* bind or connect socket */
-		bool err;
-		if (cd.server) err = !bindInetSocket(cd.rhd.socket, eport->value(), 1,
-											 &serror);
-		else err = !connectInetSocket(cd.rhd.socket, eport->value(),
-									  QFile::encodeName(cd.serverName), &serror);
-		if (err) R_ERROR_BOX(serror, QString::null);
-		
-		/* ok */
-		if ( !cd.server ) kconf->writeEntry(MP_SERVER_ADDRESS,
-											eserver->text());
-		kconf->writeEntry(MP_PORT, eport->value());
-	}
-	
 	kconf->writeEntry(MP_GAMETYPE, (int)type);
 	for (uint i=0; i<wl->size(); i++) {
 		kconf->writeEntry(QString(MP_PLAYER_TYPE).arg(i),
 						  (int)wl->widget(i)->type());
 		kconf->writeEntry(QString(MP_PLAYER_NAME).arg(i), name(i));
 	}
-	
+
 	KWizard::accept();
 }
 
@@ -207,6 +221,7 @@ void MPWizard::configureKeysSlot()
 {
 	uint nb = 0;
 	for (uint i=0; i<wl->size(); i++)
-		if ( wl->widget(i)->type()==PlayerCheckBox::Human ) nb++;
+		if ( wl->widget(i)->type()==PlayerComboBox::Human ) nb++;
 	emit configureKeys(nb);
 }
+#include "wizard.moc"
