@@ -31,7 +31,7 @@ class QLineEdit;
 class NewScoreDialog : public QDialog {
 public:
 	NewScoreDialog(QWidget *parent=0, const char *name=0);
-	const char *name();
+	QString text();
 
 private:
 	QLineEdit *le;
