@@ -78,7 +78,7 @@ void Game::menu()
     KStdAction::openNew(this, SLOT(newGame()), actionCollection(), "game_new");
     pause = new KAction(i18n("&Pause"), Key_F3, this, SLOT(pauseGame()),
 			actionCollection(), "game_pause");
-    new KAction(i18n("&Show Highscores..."), 0, this, SLOT(showHighScores()),
+    new KAction(i18n("&Show Highscores..."), CTRL+Key_H, this, SLOT(showHighScores()),
 		actionCollection(), "game_highscore");
     KStdAction::quit(this, SLOT(quitGame()), actionCollection(), "game_exit");
 
