@@ -9,7 +9,7 @@ class Keys : public QDialog
 {
     Q_OBJECT
 public:
-    Keys( QWidget *parent=0, const char *name=0 );
+		Keys( QWidget *parent=0, const char *name=0, int player=1 );
 private slots:
     void butRight();
     void butLeft();
@@ -31,6 +31,8 @@ private:
 
     QLabel *labels[4];
     QLabel *lab;
+	
+	int playerNum;
 };
 
 
